#!/bin/bash

# This script will change ethernet device settings and IP adresses
# to adapt to different devices and network topologies.  The default
# device is a eth0 (virtual) with a simple, single network (255.255.0.0)
# for all network devices.
# Eth1 is reserved for pass-through devices.  If eth1 is present, shut
# down eth0 and migrate the network config to eth1.  This is done because
# it is easier to manage the IP address via eth0, since we have better
# control over the MAC and can easily leverage DHCP.
# eth1 is reserved for special private networks, between a pair of 
# web and infra VM types, and/or a pair of App and DB VM types.
# If eth1 is present, set up IP's on the device and update /etc/hosts
# to ensure the connection to the VM's sibling is through eth1.


# if there is an eth1 device, set up a IP for a point-to-point network between web&infra and app&db
# remove any old host/ip info first
sed -i /etc/hosts -e '/.*-.*t.*/d' -e '/^$/d'
if [ -e /sys/class/net/eth1 ]; then
    vmtype=`hostname -s | sed -e s/.*-// -e s/t..//`
    tile=`hostname -s | sed -e s/sv2-${vmtype}t// -e s/^0*//`
    web_eth1_ip="192.132.${tile}.1"
    infra_eth1_ip="192.132.${tile}.2"
    app_eth1_ip="192.133.${tile}.1"
    db_eth1_ip="192.133.${tile}.2"
    case $vmtype in
        "web")
        sibling_hostname=`hostname -s | sed -e s/web/infra/`
        sibling_eth1_ip=$infra_eth1_ip
        my_eth1_ip=$web_eth1_ip
        ;;
        "infra")
        sibling_hostname=`hostname -s | sed -e s/infra/web/`
        sibling_eth1_ip=$web_eth1_ip
        my_eth1_ip=$infra_eth1_ip
        ;;
        "app")
        sibling_hostname=`hostname -s | sed -e s/app/db/`
        sibling_eth1_ip=$db_eth1_ip
        my_eth1_ip=$app_eth1_ip
        ;;
        "db")
        sibling_hostname=`hostname -s | sed -e s/db/app/`
        sibling_eth1_ip=$app_eth1_ip
        my_eth1_ip=$db_eth1_ip
        ;;
    esac
    printf "$sibling_eth1_ip\t\t$sibling_hostname\n" >>/etc/hosts
    ifconfig eth1 $my_eth1_ip netmask 255.255.255.0 up
fi
